# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Zone as ScwZone,
)
from scaleway_core.utils import (
    WaitForOptions,
    random_name,
    validate_path_param,
    fetch_all_pages,
    wait_for_resource,
)
from .types import (
    GatewayNetworkStatus,
    GatewayStatus,
    ListGatewayNetworksRequestOrderBy,
    ListGatewaysRequestOrderBy,
    ListIPsRequestOrderBy,
    ListPatRulesRequestOrderBy,
    PatRuleProtocol,
    AddBastionAllowedIPsRequest,
    AddBastionAllowedIPsResponse,
    CreateGatewayNetworkRequest,
    CreateGatewayRequest,
    CreateIPRequest,
    CreatePatRuleRequest,
    Gateway,
    GatewayNetwork,
    IP,
    ListGatewayNetworksResponse,
    ListGatewayTypesResponse,
    ListGatewaysResponse,
    ListIPsResponse,
    ListPatRulesResponse,
    PatRule,
    SetBastionAllowedIPsRequest,
    SetBastionAllowedIPsResponse,
    SetPatRulesRequest,
    SetPatRulesRequestRule,
    SetPatRulesResponse,
    UpdateGatewayNetworkRequest,
    UpdateGatewayRequest,
    UpdateIPRequest,
    UpdatePatRuleRequest,
    UpgradeGatewayRequest,
)
from .content import (
    GATEWAY_NETWORK_TRANSIENT_STATUSES,
    GATEWAY_TRANSIENT_STATUSES,
)
from .marshalling import (
    unmarshal_GatewayNetwork,
    unmarshal_IP,
    unmarshal_Gateway,
    unmarshal_PatRule,
    unmarshal_AddBastionAllowedIPsResponse,
    unmarshal_ListGatewayNetworksResponse,
    unmarshal_ListGatewayTypesResponse,
    unmarshal_ListGatewaysResponse,
    unmarshal_ListIPsResponse,
    unmarshal_ListPatRulesResponse,
    unmarshal_SetBastionAllowedIPsResponse,
    unmarshal_SetPatRulesResponse,
    marshal_AddBastionAllowedIPsRequest,
    marshal_CreateGatewayNetworkRequest,
    marshal_CreateGatewayRequest,
    marshal_CreateIPRequest,
    marshal_CreatePatRuleRequest,
    marshal_SetBastionAllowedIPsRequest,
    marshal_SetPatRulesRequest,
    marshal_UpdateGatewayNetworkRequest,
    marshal_UpdateGatewayRequest,
    marshal_UpdateIPRequest,
    marshal_UpdatePatRuleRequest,
    marshal_UpgradeGatewayRequest,
)


class VpcgwV2API(API):
    """
    This API allows you to manage your Public Gateways.
    """

    def list_gateways(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListGatewaysRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
        types: Optional[List[str]] = None,
        status: Optional[List[GatewayStatus]] = None,
        private_network_ids: Optional[List[str]] = None,
        include_legacy: Optional[bool] = None,
    ) -> ListGatewaysResponse:
        """
        List Public Gateways.
        List Public Gateways in a given Scaleway Organization or Project. By default, results are displayed in ascending order of creation date.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number to return.
        :param page_size: Gateways per page.
        :param organization_id: Include only gateways in this Organization.
        :param project_id: Include only gateways in this Project.
        :param name: Filter for gateways which have this search term in their name.
        :param tags: Filter for gateways with these tags.
        :param types: Filter for gateways of these types.
        :param status: Filter for gateways with these status. Use `unknown` to include all statuses.
        :param private_network_ids: Filter for gateways attached to these Private Networks.
        :param include_legacy: Include also legacy gateways.
        :return: :class:`ListGatewaysResponse <ListGatewaysResponse>`

        Usage:
        ::

            result = api.list_gateways()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/gateways",
            params={
                "include_legacy": include_legacy,
                "name": name,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "private_network_ids": private_network_ids,
                "project_id": project_id or self.client.default_project_id,
                "status": status,
                "tags": tags,
                "types": types,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListGatewaysResponse(res.json())

    def list_gateways_all(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListGatewaysRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
        types: Optional[List[str]] = None,
        status: Optional[List[GatewayStatus]] = None,
        private_network_ids: Optional[List[str]] = None,
        include_legacy: Optional[bool] = None,
    ) -> List[Gateway]:
        """
        List Public Gateways.
        List Public Gateways in a given Scaleway Organization or Project. By default, results are displayed in ascending order of creation date.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number to return.
        :param page_size: Gateways per page.
        :param organization_id: Include only gateways in this Organization.
        :param project_id: Include only gateways in this Project.
        :param name: Filter for gateways which have this search term in their name.
        :param tags: Filter for gateways with these tags.
        :param types: Filter for gateways of these types.
        :param status: Filter for gateways with these status. Use `unknown` to include all statuses.
        :param private_network_ids: Filter for gateways attached to these Private Networks.
        :param include_legacy: Include also legacy gateways.
        :return: :class:`List[Gateway] <List[Gateway]>`

        Usage:
        ::

            result = api.list_gateways_all()
        """

        return fetch_all_pages(
            type=ListGatewaysResponse,
            key="gateways",
            fetcher=self.list_gateways,
            args={
                "zone": zone,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "organization_id": organization_id,
                "project_id": project_id,
                "name": name,
                "tags": tags,
                "types": types,
                "status": status,
                "private_network_ids": private_network_ids,
                "include_legacy": include_legacy,
            },
        )

    def get_gateway(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
    ) -> Gateway:
        """
        Get a Public Gateway.
        Get details of a Public Gateway, specified by its gateway ID. The response object contains full details of the gateway, including its **name**, **type**, **status** and more.
        :param gateway_id: ID of the gateway to fetch.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.get_gateway(
                gateway_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def wait_for_gateway(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
        options: Optional[WaitForOptions[Gateway, bool]] = None,
    ) -> Gateway:
        """
        Get a Public Gateway.
        Get details of a Public Gateway, specified by its gateway ID. The response object contains full details of the gateway, including its **name**, **type**, **status** and more.
        :param gateway_id: ID of the gateway to fetch.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.get_gateway(
                gateway_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in GATEWAY_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_gateway,
            options=options,
            args={
                "gateway_id": gateway_id,
                "zone": zone,
            },
        )

    def create_gateway(
        self,
        *,
        type_: str,
        enable_smtp: bool,
        enable_bastion: bool,
        zone: Optional[ScwZone] = None,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
        ip_id: Optional[str] = None,
        bastion_port: Optional[int] = None,
    ) -> Gateway:
        """
        Create a Public Gateway.
        Create a new Public Gateway in the specified Scaleway Project, defining its **name**, **type** and other configuration details such as whether to enable SSH bastion.
        :param type_: Gateway type (commercial offer type).
        :param enable_smtp: Defines whether SMTP traffic should be allowed pass through the gateway.
        :param enable_bastion: Defines whether SSH bastion should be enabled the gateway.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param project_id: Scaleway Project to create the gateway in.
        :param name: Name for the gateway.
        :param tags: Tags for the gateway.
        :param ip_id: Existing IP address to attach to the gateway.
        :param bastion_port: Port of the SSH bastion.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.create_gateway(
                type="example",
                enable_smtp=False,
                enable_bastion=False,
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/gateways",
            body=marshal_CreateGatewayRequest(
                CreateGatewayRequest(
                    type_=type_,
                    enable_smtp=enable_smtp,
                    enable_bastion=enable_bastion,
                    zone=zone,
                    project_id=project_id,
                    name=name or random_name(prefix="gw"),
                    tags=tags,
                    ip_id=ip_id,
                    bastion_port=bastion_port,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def update_gateway(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
        enable_bastion: Optional[bool] = None,
        bastion_port: Optional[int] = None,
        enable_smtp: Optional[bool] = None,
    ) -> Gateway:
        """
        Update a Public Gateway.
        Update the parameters of an existing Public Gateway, for example, its **name**, **tags**, **SSH bastion configuration**, and **DNS servers**.
        :param gateway_id: ID of the gateway to update.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param name: Name for the gateway.
        :param tags: Tags for the gateway.
        :param enable_bastion: Defines whether SSH bastion should be enabled the gateway.
        :param bastion_port: Port of the SSH bastion.
        :param enable_smtp: Defines whether SMTP traffic should be allowed to pass through the gateway.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.update_gateway(
                gateway_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "PATCH",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}",
            body=marshal_UpdateGatewayRequest(
                UpdateGatewayRequest(
                    gateway_id=gateway_id,
                    zone=zone,
                    name=name,
                    tags=tags,
                    enable_bastion=enable_bastion,
                    bastion_port=bastion_port,
                    enable_smtp=enable_smtp,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def delete_gateway(
        self,
        *,
        gateway_id: str,
        delete_ip: bool,
        zone: Optional[ScwZone] = None,
    ) -> Gateway:
        """
        Delete a Public Gateway.
        Delete an existing Public Gateway, specified by its gateway ID. This action is irreversible.
        :param gateway_id: ID of the gateway to delete.
        :param delete_ip: Defines whether the PGW's IP should be deleted.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.delete_gateway(
                gateway_id="example",
                delete_ip=False,
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "DELETE",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}",
            params={
                "delete_ip": delete_ip,
            },
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def upgrade_gateway(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
        type_: Optional[str] = None,
    ) -> Gateway:
        """
        Upgrade a Public Gateway to the latest version and/or to a different commercial offer type.
        Upgrade a given Public Gateway to the newest software version or to a different commercial offer type. This applies the latest bugfixes and features to your Public Gateway. Note that gateway service will be interrupted during the update.
        :param gateway_id: ID of the gateway to upgrade.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param type_: Gateway type (commercial offer).
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.upgrade_gateway(
                gateway_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}/upgrade",
            body=marshal_UpgradeGatewayRequest(
                UpgradeGatewayRequest(
                    gateway_id=gateway_id,
                    zone=zone,
                    type_=type_,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def list_gateway_networks(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListGatewayNetworksRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        status: Optional[List[GatewayNetworkStatus]] = None,
        gateway_ids: Optional[List[str]] = None,
        private_network_ids: Optional[List[str]] = None,
        masquerade_enabled: Optional[bool] = None,
    ) -> ListGatewayNetworksResponse:
        """
        List Public Gateway connections to Private Networks.
        List the connections between Public Gateways and Private Networks (a connection = a GatewayNetwork). You can choose to filter by `gateway-id` to list all Private Networks attached to the specified Public Gateway, or by `private_network_id` to list all Public Gateways attached to the specified Private Network. Other query parameters are also available. The result is an array of GatewayNetwork objects, each giving details of the connection between a given Public Gateway and a given Private Network.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: GatewayNetworks per page.
        :param status: Filter for GatewayNetworks with these status. Use `unknown` to include all statuses.
        :param gateway_ids: Filter for GatewayNetworks connected to these gateways.
        :param private_network_ids: Filter for GatewayNetworks connected to these Private Networks.
        :param masquerade_enabled: Filter for GatewayNetworks with this `enable_masquerade` setting.
        :return: :class:`ListGatewayNetworksResponse <ListGatewayNetworksResponse>`

        Usage:
        ::

            result = api.list_gateway_networks()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-networks",
            params={
                "gateway_ids": gateway_ids,
                "masquerade_enabled": masquerade_enabled,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "private_network_ids": private_network_ids,
                "status": status,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListGatewayNetworksResponse(res.json())

    def list_gateway_networks_all(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListGatewayNetworksRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        status: Optional[List[GatewayNetworkStatus]] = None,
        gateway_ids: Optional[List[str]] = None,
        private_network_ids: Optional[List[str]] = None,
        masquerade_enabled: Optional[bool] = None,
    ) -> List[GatewayNetwork]:
        """
        List Public Gateway connections to Private Networks.
        List the connections between Public Gateways and Private Networks (a connection = a GatewayNetwork). You can choose to filter by `gateway-id` to list all Private Networks attached to the specified Public Gateway, or by `private_network_id` to list all Public Gateways attached to the specified Private Network. Other query parameters are also available. The result is an array of GatewayNetwork objects, each giving details of the connection between a given Public Gateway and a given Private Network.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: GatewayNetworks per page.
        :param status: Filter for GatewayNetworks with these status. Use `unknown` to include all statuses.
        :param gateway_ids: Filter for GatewayNetworks connected to these gateways.
        :param private_network_ids: Filter for GatewayNetworks connected to these Private Networks.
        :param masquerade_enabled: Filter for GatewayNetworks with this `enable_masquerade` setting.
        :return: :class:`List[GatewayNetwork] <List[GatewayNetwork]>`

        Usage:
        ::

            result = api.list_gateway_networks_all()
        """

        return fetch_all_pages(
            type=ListGatewayNetworksResponse,
            key="gateway_networks",
            fetcher=self.list_gateway_networks,
            args={
                "zone": zone,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "status": status,
                "gateway_ids": gateway_ids,
                "private_network_ids": private_network_ids,
                "masquerade_enabled": masquerade_enabled,
            },
        )

    def get_gateway_network(
        self,
        *,
        gateway_network_id: str,
        zone: Optional[ScwZone] = None,
    ) -> GatewayNetwork:
        """
        Get a Public Gateway connection to a Private Network.
        Get details of a given connection between a Public Gateway and a Private Network (this connection = a GatewayNetwork), specified by its `gateway_network_id`. The response object contains details of the connection including the IDs of the Public Gateway and Private Network, the dates the connection was created/updated and its configuration settings.
        :param gateway_network_id: ID of the GatewayNetwork to fetch.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`GatewayNetwork <GatewayNetwork>`

        Usage:
        ::

            result = api.get_gateway_network(
                gateway_network_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_network_id = validate_path_param(
            "gateway_network_id", gateway_network_id
        )

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-networks/{param_gateway_network_id}",
        )

        self._throw_on_error(res)
        return unmarshal_GatewayNetwork(res.json())

    def wait_for_gateway_network(
        self,
        *,
        gateway_network_id: str,
        zone: Optional[ScwZone] = None,
        options: Optional[WaitForOptions[GatewayNetwork, bool]] = None,
    ) -> GatewayNetwork:
        """
        Get a Public Gateway connection to a Private Network.
        Get details of a given connection between a Public Gateway and a Private Network (this connection = a GatewayNetwork), specified by its `gateway_network_id`. The response object contains details of the connection including the IDs of the Public Gateway and Private Network, the dates the connection was created/updated and its configuration settings.
        :param gateway_network_id: ID of the GatewayNetwork to fetch.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`GatewayNetwork <GatewayNetwork>`

        Usage:
        ::

            result = api.get_gateway_network(
                gateway_network_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = (
                lambda res: res.status not in GATEWAY_NETWORK_TRANSIENT_STATUSES
            )

        return wait_for_resource(
            fetcher=self.get_gateway_network,
            options=options,
            args={
                "gateway_network_id": gateway_network_id,
                "zone": zone,
            },
        )

    def create_gateway_network(
        self,
        *,
        gateway_id: str,
        private_network_id: str,
        enable_masquerade: bool,
        push_default_route: bool,
        zone: Optional[ScwZone] = None,
        ipam_ip_id: Optional[str] = None,
    ) -> GatewayNetwork:
        """
        Attach a Public Gateway to a Private Network.
        Attach a specific Public Gateway to a specific Private Network (create a GatewayNetwork). You can configure parameters for the connection including whether to enable masquerade (dynamic NAT), and more.
        :param gateway_id: Public Gateway to connect.
        :param private_network_id: Private Network to connect.
        :param enable_masquerade: Defines whether to enable masquerade (dynamic NAT) on the GatewayNetwork.
        :param push_default_route: Enabling the default route also enables masquerading.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param ipam_ip_id: Use this IPAM-booked IP ID as the Gateway's IP in this Private Network.
        :return: :class:`GatewayNetwork <GatewayNetwork>`

        Usage:
        ::

            result = api.create_gateway_network(
                gateway_id="example",
                private_network_id="example",
                enable_masquerade=False,
                push_default_route=False,
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-networks",
            body=marshal_CreateGatewayNetworkRequest(
                CreateGatewayNetworkRequest(
                    gateway_id=gateway_id,
                    private_network_id=private_network_id,
                    enable_masquerade=enable_masquerade,
                    push_default_route=push_default_route,
                    zone=zone,
                    ipam_ip_id=ipam_ip_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_GatewayNetwork(res.json())

    def update_gateway_network(
        self,
        *,
        gateway_network_id: str,
        zone: Optional[ScwZone] = None,
        enable_masquerade: Optional[bool] = None,
        push_default_route: Optional[bool] = None,
        ipam_ip_id: Optional[str] = None,
    ) -> GatewayNetwork:
        """
        Update a Public Gateway's connection to a Private Network.
        Update the configuration parameters of a connection between a given Public Gateway and Private Network (the connection = a GatewayNetwork). Updatable parameters include whether to enable traffic masquerade (dynamic NAT).
        :param gateway_network_id: ID of the GatewayNetwork to update.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param enable_masquerade: Defines whether to enable masquerade (dynamic NAT) on the GatewayNetwork.
        :param push_default_route: Enabling the default route also enables masquerading.
        :param ipam_ip_id: Use this IPAM-booked IP ID as the Gateway's IP in this Private Network.
        :return: :class:`GatewayNetwork <GatewayNetwork>`

        Usage:
        ::

            result = api.update_gateway_network(
                gateway_network_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_network_id = validate_path_param(
            "gateway_network_id", gateway_network_id
        )

        res = self._request(
            "PATCH",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-networks/{param_gateway_network_id}",
            body=marshal_UpdateGatewayNetworkRequest(
                UpdateGatewayNetworkRequest(
                    gateway_network_id=gateway_network_id,
                    zone=zone,
                    enable_masquerade=enable_masquerade,
                    push_default_route=push_default_route,
                    ipam_ip_id=ipam_ip_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_GatewayNetwork(res.json())

    def delete_gateway_network(
        self,
        *,
        gateway_network_id: str,
        zone: Optional[ScwZone] = None,
    ) -> GatewayNetwork:
        """
        Detach a Public Gateway from a Private Network.
        Detach a given Public Gateway from a given Private Network, i.e. delete a GatewayNetwork specified by a gateway_network_id.
        :param gateway_network_id: ID of the GatewayNetwork to delete.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`GatewayNetwork <GatewayNetwork>`

        Usage:
        ::

            result = api.delete_gateway_network(
                gateway_network_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_network_id = validate_path_param(
            "gateway_network_id", gateway_network_id
        )

        res = self._request(
            "DELETE",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-networks/{param_gateway_network_id}",
        )

        self._throw_on_error(res)
        return unmarshal_GatewayNetwork(res.json())

    def list_pat_rules(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListPatRulesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        gateway_ids: Optional[List[str]] = None,
        private_ips: Optional[List[str]] = None,
        protocol: Optional[PatRuleProtocol] = None,
    ) -> ListPatRulesResponse:
        """
        List PAT rules.
        List PAT rules. You can filter by gateway ID to list all PAT rules for a particular gateway, or filter for PAT rules targeting a specific IP address or using a specific protocol.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: PAT rules per page.
        :param gateway_ids: Filter for PAT rules on these gateways.
        :param private_ips: Filter for PAT rules targeting these private ips.
        :param protocol: Filter for PAT rules with this protocol.
        :return: :class:`ListPatRulesResponse <ListPatRulesResponse>`

        Usage:
        ::

            result = api.list_pat_rules()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules",
            params={
                "gateway_ids": gateway_ids,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "private_ips": private_ips,
                "protocol": protocol,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListPatRulesResponse(res.json())

    def list_pat_rules_all(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListPatRulesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        gateway_ids: Optional[List[str]] = None,
        private_ips: Optional[List[str]] = None,
        protocol: Optional[PatRuleProtocol] = None,
    ) -> List[PatRule]:
        """
        List PAT rules.
        List PAT rules. You can filter by gateway ID to list all PAT rules for a particular gateway, or filter for PAT rules targeting a specific IP address or using a specific protocol.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: PAT rules per page.
        :param gateway_ids: Filter for PAT rules on these gateways.
        :param private_ips: Filter for PAT rules targeting these private ips.
        :param protocol: Filter for PAT rules with this protocol.
        :return: :class:`List[PatRule] <List[PatRule]>`

        Usage:
        ::

            result = api.list_pat_rules_all()
        """

        return fetch_all_pages(
            type=ListPatRulesResponse,
            key="pat_rules",
            fetcher=self.list_pat_rules,
            args={
                "zone": zone,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "gateway_ids": gateway_ids,
                "private_ips": private_ips,
                "protocol": protocol,
            },
        )

    def get_pat_rule(
        self,
        *,
        pat_rule_id: str,
        zone: Optional[ScwZone] = None,
    ) -> PatRule:
        """
        Get a PAT rule.
        Get a PAT rule, specified by its PAT rule ID. The response object gives full details of the PAT rule, including the Public Gateway it belongs to and the configuration settings in terms of public / private ports, private IP and protocol.
        :param pat_rule_id: ID of the PAT rule to get.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`PatRule <PatRule>`

        Usage:
        ::

            result = api.get_pat_rule(
                pat_rule_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_pat_rule_id = validate_path_param("pat_rule_id", pat_rule_id)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules/{param_pat_rule_id}",
        )

        self._throw_on_error(res)
        return unmarshal_PatRule(res.json())

    def create_pat_rule(
        self,
        *,
        gateway_id: str,
        public_port: int,
        private_ip: str,
        private_port: int,
        zone: Optional[ScwZone] = None,
        protocol: Optional[PatRuleProtocol] = None,
    ) -> PatRule:
        """
        Create a PAT rule.
        Create a new PAT rule on a specified Public Gateway, defining the protocol to use, public port to listen on, and private port / IP address to map to.
        :param gateway_id: ID of the Gateway on which to create the rule.
        :param public_port: Public port to listen on.
        :param private_ip: Private IP to forward data to.
        :param private_port: Private port to translate to.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param protocol: Protocol the rule should apply to.
        :return: :class:`PatRule <PatRule>`

        Usage:
        ::

            result = api.create_pat_rule(
                gateway_id="example",
                public_port=1,
                private_ip="example",
                private_port=1,
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules",
            body=marshal_CreatePatRuleRequest(
                CreatePatRuleRequest(
                    gateway_id=gateway_id,
                    public_port=public_port,
                    private_ip=private_ip,
                    private_port=private_port,
                    zone=zone,
                    protocol=protocol,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_PatRule(res.json())

    def update_pat_rule(
        self,
        *,
        pat_rule_id: str,
        zone: Optional[ScwZone] = None,
        public_port: Optional[int] = None,
        private_ip: Optional[str] = None,
        private_port: Optional[int] = None,
        protocol: Optional[PatRuleProtocol] = None,
    ) -> PatRule:
        """
        Update a PAT rule.
        Update a PAT rule, specified by its PAT rule ID. Configuration settings including private/public port, private IP address and protocol can all be updated.
        :param pat_rule_id: ID of the PAT rule to update.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param public_port: Public port to listen on.
        :param private_ip: Private IP to forward data to.
        :param private_port: Private port to translate to.
        :param protocol: Protocol the rule should apply to.
        :return: :class:`PatRule <PatRule>`

        Usage:
        ::

            result = api.update_pat_rule(
                pat_rule_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_pat_rule_id = validate_path_param("pat_rule_id", pat_rule_id)

        res = self._request(
            "PATCH",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules/{param_pat_rule_id}",
            body=marshal_UpdatePatRuleRequest(
                UpdatePatRuleRequest(
                    pat_rule_id=pat_rule_id,
                    zone=zone,
                    public_port=public_port,
                    private_ip=private_ip,
                    private_port=private_port,
                    protocol=protocol,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_PatRule(res.json())

    def set_pat_rules(
        self,
        *,
        gateway_id: str,
        pat_rules: List[SetPatRulesRequestRule],
        zone: Optional[ScwZone] = None,
    ) -> SetPatRulesResponse:
        """
        Set all PAT rules.
        Set a definitive list of PAT rules attached to a Public Gateway. Each rule is identified by its public port and protocol. This will sync the current PAT rule list on the gateway with the new list, creating, updating or deleting PAT rules accordingly.
        :param gateway_id: ID of the gateway on which to set the PAT rules.
        :param pat_rules: New list of PAT rules.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`SetPatRulesResponse <SetPatRulesResponse>`

        Usage:
        ::

            result = api.set_pat_rules(
                gateway_id="example",
                pat_rules=[],
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "PUT",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules",
            body=marshal_SetPatRulesRequest(
                SetPatRulesRequest(
                    gateway_id=gateway_id,
                    pat_rules=pat_rules,
                    zone=zone,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SetPatRulesResponse(res.json())

    def delete_pat_rule(
        self,
        *,
        pat_rule_id: str,
        zone: Optional[ScwZone] = None,
    ) -> None:
        """
        Delete a PAT rule.
        Delete a PAT rule, identified by its PAT rule ID. This action is irreversible.
        :param pat_rule_id: ID of the PAT rule to delete.
        :param zone: Zone to target. If none is passed will use default zone from the config.

        Usage:
        ::

            result = api.delete_pat_rule(
                pat_rule_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_pat_rule_id = validate_path_param("pat_rule_id", pat_rule_id)

        res = self._request(
            "DELETE",
            f"/vpc-gw/v2/zones/{param_zone}/pat-rules/{param_pat_rule_id}",
        )

        self._throw_on_error(res)

    def list_gateway_types(
        self,
        *,
        zone: Optional[ScwZone] = None,
    ) -> ListGatewayTypesResponse:
        """
        List Public Gateway types.
        List the different Public Gateway commercial offer types available at Scaleway. The response is an array of objects describing the name and technical details of each available gateway type.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`ListGatewayTypesResponse <ListGatewayTypesResponse>`

        Usage:
        ::

            result = api.list_gateway_types()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/gateway-types",
        )

        self._throw_on_error(res)
        return unmarshal_ListGatewayTypesResponse(res.json())

    def list_i_ps(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListIPsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        reverse: Optional[str] = None,
        is_free: Optional[bool] = None,
    ) -> ListIPsResponse:
        """
        List IPs.
        List Public Gateway flexible IP addresses. A number of filter options are available for limiting results in the response.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: IP addresses per page.
        :param organization_id: Include only gateways in this Organization.
        :param project_id: Filter for IP addresses in this Project.
        :param tags: Filter for IP addresses with these tags.
        :param reverse: Filter for IP addresses that have a reverse containing this string.
        :param is_free: Filter based on whether the IP is attached to a gateway or not.
        :return: :class:`ListIPsResponse <ListIPsResponse>`

        Usage:
        ::

            result = api.list_i_ps()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/ips",
            params={
                "is_free": is_free,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "reverse": reverse,
                "tags": tags,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListIPsResponse(res.json())

    def list_i_ps_all(
        self,
        *,
        zone: Optional[ScwZone] = None,
        order_by: Optional[ListIPsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        reverse: Optional[str] = None,
        is_free: Optional[bool] = None,
    ) -> List[IP]:
        """
        List IPs.
        List Public Gateway flexible IP addresses. A number of filter options are available for limiting results in the response.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param order_by: Order in which to return results.
        :param page: Page number.
        :param page_size: IP addresses per page.
        :param organization_id: Include only gateways in this Organization.
        :param project_id: Filter for IP addresses in this Project.
        :param tags: Filter for IP addresses with these tags.
        :param reverse: Filter for IP addresses that have a reverse containing this string.
        :param is_free: Filter based on whether the IP is attached to a gateway or not.
        :return: :class:`List[IP] <List[IP]>`

        Usage:
        ::

            result = api.list_i_ps_all()
        """

        return fetch_all_pages(
            type=ListIPsResponse,
            key="ips",
            fetcher=self.list_i_ps,
            args={
                "zone": zone,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "organization_id": organization_id,
                "project_id": project_id,
                "tags": tags,
                "reverse": reverse,
                "is_free": is_free,
            },
        )

    def get_ip(
        self,
        *,
        ip_id: str,
        zone: Optional[ScwZone] = None,
    ) -> IP:
        """
        Get an IP.
        Get details of a Public Gateway flexible IP address, identified by its IP ID. The response object contains information including which (if any) Public Gateway using this IP address, the reverse and various other metadata.
        :param ip_id: ID of the IP address to get.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.get_ip(
                ip_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "GET",
            f"/vpc-gw/v2/zones/{param_zone}/ips/{param_ip_id}",
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def create_ip(
        self,
        *,
        zone: Optional[ScwZone] = None,
        project_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
    ) -> IP:
        """
        Reserve an IP.
        Create (reserve) a new flexible IP address that can be used for a Public Gateway in a specified Scaleway Project.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param project_id: Project to create the IP address in.
        :param tags: Tags to give to the IP address.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.create_ip()
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/ips",
            body=marshal_CreateIPRequest(
                CreateIPRequest(
                    zone=zone,
                    project_id=project_id,
                    tags=tags,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def update_ip(
        self,
        *,
        ip_id: str,
        zone: Optional[ScwZone] = None,
        tags: Optional[List[str]] = None,
        reverse: Optional[str] = None,
        gateway_id: Optional[str] = None,
    ) -> IP:
        """
        Update an IP.
        Update details of an existing flexible IP address, including its tags, reverse and the Public Gateway it is assigned to.
        :param ip_id: ID of the IP address to update.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param tags: Tags to give to the IP address.
        :param reverse: Reverse to set on the address. Empty string to unset.
        :param gateway_id: Gateway to attach the IP address to. Empty string to detach.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.update_ip(
                ip_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "PATCH",
            f"/vpc-gw/v2/zones/{param_zone}/ips/{param_ip_id}",
            body=marshal_UpdateIPRequest(
                UpdateIPRequest(
                    ip_id=ip_id,
                    zone=zone,
                    tags=tags,
                    reverse=reverse,
                    gateway_id=gateway_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def delete_ip(
        self,
        *,
        ip_id: str,
        zone: Optional[ScwZone] = None,
    ) -> None:
        """
        Delete an IP.
        Delete a flexible IP address from your account. This action is irreversible.
        :param ip_id: ID of the IP address to delete.
        :param zone: Zone to target. If none is passed will use default zone from the config.

        Usage:
        ::

            result = api.delete_ip(
                ip_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "DELETE",
            f"/vpc-gw/v2/zones/{param_zone}/ips/{param_ip_id}",
        )

        self._throw_on_error(res)

    def refresh_ssh_keys(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
    ) -> Gateway:
        """
        Refresh a Public Gateway's SSH keys.
        Refresh the SSH keys of a given Public Gateway, specified by its gateway ID. This adds any new SSH keys in the gateway's Scaleway Project to the gateway itself.
        :param gateway_id: ID of the gateway to refresh SSH keys on.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`Gateway <Gateway>`

        Usage:
        ::

            result = api.refresh_ssh_keys(
                gateway_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}/refresh-ssh-keys",
            body={},
        )

        self._throw_on_error(res)
        return unmarshal_Gateway(res.json())

    def add_bastion_allowed_i_ps(
        self,
        *,
        gateway_id: str,
        ip_range: str,
        zone: Optional[ScwZone] = None,
    ) -> AddBastionAllowedIPsResponse:
        """
        Add allowed IP range to SSH bastion.
        Add an IP range (in CIDR notation) to be allowed to connect to the SSH bastion.
        :param gateway_id: ID of the gateway to add the allowed IP range to.
        :param ip_range: IP range allowed to connect to the SSH bastion.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :return: :class:`AddBastionAllowedIPsResponse <AddBastionAllowedIPsResponse>`

        Usage:
        ::

            result = api.add_bastion_allowed_i_ps(
                gateway_id="example",
                ip_range="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "POST",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}/bastion-allowed-ips",
            body=marshal_AddBastionAllowedIPsRequest(
                AddBastionAllowedIPsRequest(
                    gateway_id=gateway_id,
                    ip_range=ip_range,
                    zone=zone,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_AddBastionAllowedIPsResponse(res.json())

    def set_bastion_allowed_i_ps(
        self,
        *,
        gateway_id: str,
        zone: Optional[ScwZone] = None,
        ip_ranges: Optional[List[str]] = None,
    ) -> SetBastionAllowedIPsResponse:
        """
        Set all IP ranges allowed for SSH bastion.
        Set a definitive list of IP ranges (in CIDR notation) allowed to connect to the SSH bastion.
        :param gateway_id: ID of the gateway on which to set the allowed IP range.
        :param zone: Zone to target. If none is passed will use default zone from the config.
        :param ip_ranges: New list of IP ranges (each range in CIDR notation) allowed to connect to the SSH bastion.
        :return: :class:`SetBastionAllowedIPsResponse <SetBastionAllowedIPsResponse>`

        Usage:
        ::

            result = api.set_bastion_allowed_i_ps(
                gateway_id="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)

        res = self._request(
            "PUT",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}/bastion-allowed-ips",
            body=marshal_SetBastionAllowedIPsRequest(
                SetBastionAllowedIPsRequest(
                    gateway_id=gateway_id,
                    zone=zone,
                    ip_ranges=ip_ranges,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SetBastionAllowedIPsResponse(res.json())

    def delete_bastion_allowed_i_ps(
        self,
        *,
        gateway_id: str,
        ip_range: str,
        zone: Optional[ScwZone] = None,
    ) -> None:
        """
        Delete allowed IP range from SSH bastion.
        Delete an IP range (defined in CIDR notation) from SSH bastion, so that it is no longer allowed to connect.
        :param gateway_id: ID of the gateway on which to delete the allowed IP range.
        :param ip_range: IP range to delete from SSH bastion's list of allowed IPs.
        :param zone: Zone to target. If none is passed will use default zone from the config.

        Usage:
        ::

            result = api.delete_bastion_allowed_i_ps(
                gateway_id="example",
                ip_range="example",
            )
        """

        param_zone = validate_path_param("zone", zone or self.client.default_zone)
        param_gateway_id = validate_path_param("gateway_id", gateway_id)
        param_ip_range = validate_path_param("ip_range", ip_range)

        res = self._request(
            "DELETE",
            f"/vpc-gw/v2/zones/{param_zone}/gateways/{param_gateway_id}/bastion-allowed-ips/{param_ip_range}",
        )

        self._throw_on_error(res)



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from typing import List

from .types import (
    PipelineStatus,
    PurgeRequestStatus,
)

PIPELINE_TRANSIENT_STATUSES: List[PipelineStatus] = [
    PipelineStatus.PENDING,
]
"""
Lists transient statutes of the enum :class:`PipelineStatus <PipelineStatus>`.
"""
PURGE_REQUEST_TRANSIENT_STATUSES: List[PurgeRequestStatus] = [
    PurgeRequestStatus.PENDING,
]
"""
Lists transient statutes of the enum :class:`PurgeRequestStatus <PurgeRequestStatus>`.
"""



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import Dict, List, Optional

from scaleway_core.bridge import (
    Zone as ScwZone,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class ListServerPrivateNetworksRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ServerPrivateNetworkStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATUS = "unknown_status"
    ATTACHING = "attaching"
    ATTACHED = "attached"
    ERROR = "error"
    DETACHING = "detaching"
    LOCKED = "locked"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class ServerPrivateNetwork:
    id: str
    """
    UUID of the Server-to-Private Network mapping.
    """

    project_id: str
    """
    Private Network Project UUID.
    """

    server_id: str
    """
    Server UUID.
    """

    private_network_id: str
    """
    Private Network UUID.
    """

    status: ServerPrivateNetworkStatus
    """
    Configuration status of the Private Network.
    """

    ipam_ip_ids: List[str]
    """
    IPAM IP IDs of the server, if it has any.
    """

    vlan: Optional[int]
    """
    VLAN UUID associated with the Private Network.
    """

    created_at: Optional[datetime]
    """
    Private Network creation date.
    """

    updated_at: Optional[datetime]
    """
    Date the Private Network was last modified.
    """


@dataclass
class ListServerPrivateNetworksResponse:
    server_private_networks: List[ServerPrivateNetwork]

    total_count: int


@dataclass
class PrivateNetworkApiAddServerPrivateNetworkRequest:
    server_id: str
    """
    UUID of the server.
    """

    private_network_id: str
    """
    UUID of the Private Network.
    """

    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """

    ipam_ip_ids: Optional[List[str]]
    """
    IPAM IDs of an IPs to attach to the server.
    """


@dataclass
class PrivateNetworkApiDeleteServerPrivateNetworkRequest:
    server_id: str
    """
    UUID of the server.
    """

    private_network_id: str
    """
    UUID of the Private Network.
    """

    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """


@dataclass
class PrivateNetworkApiListServerPrivateNetworksRequest:
    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """

    order_by: Optional[ListServerPrivateNetworksRequestOrderBy]
    """
    Sort order for the returned Private Networks.
    """

    page: Optional[int]
    """
    Page number for the returned Private Networks.
    """

    page_size: Optional[int]
    """
    Maximum number of Private Networks per page.
    """

    server_id: Optional[str]
    """
    Filter Private Networks by server UUID.
    """

    private_network_id: Optional[str]
    """
    Filter Private Networks by Private Network UUID.
    """

    organization_id: Optional[str]
    """
    Filter Private Networks by organization UUID.
    """

    project_id: Optional[str]
    """
    Filter Private Networks by project UUID.
    """

    ipam_ip_ids: Optional[List[str]]
    """
    Filter Private Networks by IPAM IP UUIDs.
    """


@dataclass
class PrivateNetworkApiSetServerPrivateNetworksRequest:
    server_id: str
    """
    UUID of the server.
    """

    per_private_network_ipam_ip_ids: Dict[str, List[str]]
    """
    Object where the keys are the UUIDs of Private Networks and the values are arrays of IPAM IDs representing the IPs to assign to this Elastic Metal server on the Private Network. If the array supplied for a Private Network is empty, the next available IP from the Private Network's CIDR block will automatically be used for attachment.
    """

    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """


@dataclass
class SetServerPrivateNetworksResponse:
    server_private_networks: List[ServerPrivateNetwork]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import Any, Dict
from dateutil import parser

from .types import (
    KeyManagerKeyInfo,
    KubernetesACLInfo,
    KubernetesClusterInfo,
    KubernetesNodeInfo,
    KubernetesPoolInfo,
    SecretManagerSecretInfo,
    SecretManagerSecretVersionInfo,
    EventPrincipal,
    Resource,
    Event,
    ListEventsResponse,
    ProductService,
    Product,
    ListProductsResponse,
)


def unmarshal_KeyManagerKeyInfo(data: Any) -> KeyManagerKeyInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'KeyManagerKeyInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    return KeyManagerKeyInfo(**args)


def unmarshal_KubernetesACLInfo(data: Any) -> KubernetesACLInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'KubernetesACLInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    return KubernetesACLInfo(**args)


def unmarshal_KubernetesClusterInfo(data: Any) -> KubernetesClusterInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'KubernetesClusterInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    return KubernetesClusterInfo(**args)


def unmarshal_KubernetesNodeInfo(data: Any) -> KubernetesNodeInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'KubernetesNodeInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    return KubernetesNodeInfo(**args)


def unmarshal_KubernetesPoolInfo(data: Any) -> KubernetesPoolInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'KubernetesPoolInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    return KubernetesPoolInfo(**args)


def unmarshal_SecretManagerSecretInfo(data: Any) -> SecretManagerSecretInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'SecretManagerSecretInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("path", None)
    if field is not None:
        args["path"] = field

    return SecretManagerSecretInfo(**args)


def unmarshal_SecretManagerSecretVersionInfo(
    data: Any,
) -> SecretManagerSecretVersionInfo:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'SecretManagerSecretVersionInfo' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("revision", None)
    if field is not None:
        args["revision"] = field

    return SecretManagerSecretVersionInfo(**args)


def unmarshal_EventPrincipal(data: Any) -> EventPrincipal:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'EventPrincipal' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    return EventPrincipal(**args)


def unmarshal_Resource(data: Any) -> Resource:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Resource' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    field = data.get("created_at", None)
    if field is not None:
        args["created_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["created_at"] = None

    field = data.get("updated_at", None)
    if field is not None:
        args["updated_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["updated_at"] = None

    field = data.get("deleted_at", None)
    if field is not None:
        args["deleted_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["deleted_at"] = None

    field = data.get("name", None)
    if field is not None:
        args["name"] = field
    else:
        args["name"] = None

    field = data.get("secm_secret_info", None)
    if field is not None:
        args["secm_secret_info"] = unmarshal_SecretManagerSecretInfo(field)
    else:
        args["secm_secret_info"] = None

    field = data.get("secm_secret_version_info", None)
    if field is not None:
        args["secm_secret_version_info"] = unmarshal_SecretManagerSecretVersionInfo(
            field
        )
    else:
        args["secm_secret_version_info"] = None

    field = data.get("kube_cluster_info", None)
    if field is not None:
        args["kube_cluster_info"] = unmarshal_KubernetesClusterInfo(field)
    else:
        args["kube_cluster_info"] = None

    field = data.get("kube_pool_info", None)
    if field is not None:
        args["kube_pool_info"] = unmarshal_KubernetesPoolInfo(field)
    else:
        args["kube_pool_info"] = None

    field = data.get("kube_node_info", None)
    if field is not None:
        args["kube_node_info"] = unmarshal_KubernetesNodeInfo(field)
    else:
        args["kube_node_info"] = None

    field = data.get("kube_acl_info", None)
    if field is not None:
        args["kube_acl_info"] = unmarshal_KubernetesACLInfo(field)
    else:
        args["kube_acl_info"] = None

    field = data.get("keym_key_info", None)
    if field is not None:
        args["keym_key_info"] = unmarshal_KeyManagerKeyInfo(field)
    else:
        args["keym_key_info"] = None

    field = data.get("secret_manager_secret_info", None)
    if field is not None:
        args["secret_manager_secret_info"] = unmarshal_SecretManagerSecretInfo(field)
    else:
        args["secret_manager_secret_info"] = None

    field = data.get("secret_manager_version_info", None)
    if field is not None:
        args["secret_manager_version_info"] = unmarshal_SecretManagerSecretVersionInfo(
            field
        )
    else:
        args["secret_manager_version_info"] = None

    field = data.get("key_manager_key_info", None)
    if field is not None:
        args["key_manager_key_info"] = unmarshal_KeyManagerKeyInfo(field)
    else:
        args["key_manager_key_info"] = None

    return Resource(**args)


def unmarshal_Event(data: Any) -> Event:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Event' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("locality", None)
    if field is not None:
        args["locality"] = field

    field = data.get("organization_id", None)
    if field is not None:
        args["organization_id"] = field

    field = data.get("source_ip", None)
    if field is not None:
        args["source_ip"] = field

    field = data.get("recorded_at", None)
    if field is not None:
        args["recorded_at"] = (
            parser.isoparse(field) if isinstance(field, str) else field
        )
    else:
        args["recorded_at"] = None

    field = data.get("principal", None)
    if field is not None:
        args["principal"] = unmarshal_EventPrincipal(field)
    else:
        args["principal"] = None

    field = data.get("project_id", None)
    if field is not None:
        args["project_id"] = field
    else:
        args["project_id"] = None

    field = data.get("user_agent", None)
    if field is not None:
        args["user_agent"] = field
    else:
        args["user_agent"] = None

    field = data.get("product_name", None)
    if field is not None:
        args["product_name"] = field

    field = data.get("service_name", None)
    if field is not None:
        args["service_name"] = field

    field = data.get("method_name", None)
    if field is not None:
        args["method_name"] = field

    field = data.get("resources", None)
    if field is not None:
        args["resources"] = (
            [unmarshal_Resource(v) for v in field] if field is not None else None
        )

    field = data.get("request_id", None)
    if field is not None:
        args["request_id"] = field

    field = data.get("status_code", None)
    if field is not None:
        args["status_code"] = field

    field = data.get("resource", None)
    if field is not None:
        args["resource"] = unmarshal_Resource(field)
    else:
        args["resource"] = None

    field = data.get("request_body", None)
    if field is not None:
        args["request_body"] = field
    else:
        args["request_body"] = None

    return Event(**args)


def unmarshal_ListEventsResponse(data: Any) -> ListEventsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListEventsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("events", None)
    if field is not None:
        args["events"] = (
            [unmarshal_Event(v) for v in field] if field is not None else None
        )

    field = data.get("next_page_token", None)
    if field is not None:
        args["next_page_token"] = field
    else:
        args["next_page_token"] = None

    return ListEventsResponse(**args)


def unmarshal_ProductService(data: Any) -> ProductService:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ProductService' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("methods", None)
    if field is not None:
        args["methods"] = field

    return ProductService(**args)


def unmarshal_Product(data: Any) -> Product:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Product' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("title", None)
    if field is not None:
        args["title"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("services", None)
    if field is not None:
        args["services"] = (
            [unmarshal_ProductService(v) for v in field] if field is not None else None
        )

    return Product(**args)


def unmarshal_ListProductsResponse(data: Any) -> ListProductsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListProductsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("products", None)
    if field is not None:
        args["products"] = (
            [unmarshal_Product(v) for v in field] if field is not None else None
        )

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    return ListProductsResponse(**args)



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from typing import Dict, List, Optional

from scaleway_core.bridge import (
    Zone as ScwZone,
)

from .types import (
    Arch,
    BootType,
    SecurityGroupPolicy,
    SecurityGroupRuleAction,
    SecurityGroupRuleDirection,
    SecurityGroupRuleProtocol,
    ServerAction,
    ServerState,
    SnapshotState,
    VolumeVolumeType,
    ServerSummary,
    Volume,
    Image,
    PlacementGroup,
    PrivateNIC,
    SecurityGroupSummary,
    ServerIp,
    ServerIpv6,
    ServerLocation,
    ServerMaintenance,
    SnapshotBaseVolume,
    Server,
    SecurityGroup,
    SecurityGroupRule,
    Snapshot,
)


@dataclass
class _SetImageResponse:
    image: Optional[Image]


@dataclass
class _SetSecurityGroupRequest:
    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """
    id: str
    """
    UUID of the security group.
    """
    name: str
    """
    Name of the security group.
    """
    description: str
    """
    Description of the security group.
    """
    enable_default_security: bool
    """
    True to block SMTP on IPv4 and IPv6. This feature is read only, please open a support ticket if you need to make it configurable.
    """
    tags: Optional[List[str]]
    """
    Tags of the security group.
    """
    creation_date: Optional[datetime]
    """
    Creation date of the security group (will be ignored).
    """
    modification_date: Optional[datetime]
    """
    Modification date of the security group (will be ignored).
    """
    project_default: bool
    """
    True use this security group for future Instances created in this project.
    """
    stateful: bool
    """
    True to set the security group as stateful.
    """
    inbound_default_policy: Optional[SecurityGroupPolicy]
    """
    Default inbound policy.
    """
    outbound_default_policy: Optional[SecurityGroupPolicy]
    """
    Default outbound policy.
    """
    organization: Optional[str]
    """
    Security groups Organization ID.
    """
    project: Optional[str]
    """
    Security group Project ID.
    """
    organization_default: Optional[bool]
    """
    Please use project_default instead.
    """
    servers: Optional[List[ServerSummary]]
    """
    Instances attached to this security group.
    """


@dataclass
class _SetSecurityGroupResponse:
    security_group: Optional[SecurityGroup]


@dataclass
class _SetSecurityGroupRuleRequest:
    security_group_id: str
    security_group_rule_id: str
    id: str
    ip_range: str
    position: int
    editable: bool
    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """
    protocol: Optional[SecurityGroupRuleProtocol]
    direction: Optional[SecurityGroupRuleDirection]
    action: Optional[SecurityGroupRuleAction]
    dest_port_from: Optional[int]
    dest_port_to: Optional[int]


@dataclass
class _SetSecurityGroupRuleResponse:
    rule: Optional[SecurityGroupRule]


@dataclass
class _SetServerRequest:
    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """
    id: str
    """
    Instance unique ID.
    """
    name: str
    """
    Instance name.
    """
    commercial_type: str
    """
    Instance commercial type (eg. GP1-M).
    """
    organization: Optional[str]
    """
    Instance Organization ID.
    """
    dynamic_ip_required: bool
    """
    True if a dynamic IPv4 is required.
    """
    hostname: str
    """
    Instance host name.
    """
    protected: bool
    """
    Instance protection option is activated.
    """
    state_detail: str
    """
    Instance state_detail.
    """
    project: Optional[str]
    """
    Instance Project ID.
    """
    allowed_actions: Optional[List[ServerAction]]
    """
    Provide a list of allowed actions on the server.
    """
    tags: Optional[List[str]]
    """
    Tags associated with the Instance.
    """
    creation_date: Optional[datetime]
    """
    Instance creation date.
    """
    routed_ip_enabled: Optional[bool]
    """
    True to configure the instance so it uses the new routed IP mode (once this is set to True you cannot set it back to False).
    """
    enable_ipv6: Optional[bool]
    """
    True if IPv6 is enabled (deprecated and always `False` when `routed_ip_enabled` is `True`).
    """
    image: Optional[Image]
    """
    Provide information on the Instance image.
    """
    private_ip: Optional[str]
    """
    Instance private IP address (deprecated and always `null` when `routed_ip_enabled` is `True`).
    """
    public_ip: Optional[ServerIp]
    """
    Information about the public IP (deprecated in favor of `public_ips`).
    """
    public_ips: Optional[List[ServerIp]]
    """
    Information about all the public IPs attached to the server.
    """
    modification_date: Optional[datetime]
    """
    Instance modification date.
    """
    state: Optional[ServerState]
    """
    Instance state.
    """
    location: Optional[ServerLocation]
    """
    Instance location.
    """
    ipv6: Optional[ServerIpv6]
    """
    Instance IPv6 address (deprecated when `routed_ip_enabled` is `True`).
    """
    boot_type: Optional[BootType]
    """
    Instance boot type.
    """
    volumes: Optional[Dict[str, Volume]]
    """
    Instance volumes.
    """
    security_group: Optional[SecurityGroupSummary]
    """
    Instance security group.
    """
    maintenances: Optional[List[ServerMaintenance]]
    """
    Instance planned maintenances.
    """
    arch: Optional[Arch]
    """
    Instance architecture (refers to the CPU architecture used for the Instance, e.g. x86_64, arm64).
    """
    placement_group: Optional[PlacementGroup]
    """
    Instance placement group.
    """
    private_nics: Optional[List[PrivateNIC]]
    """
    Instance private NICs.
    """
    admin_password_encryption_ssh_key_id: Optional[str]
    """
    The public_key value of this key is used to encrypt the admin password. When set to an empty string, reset this value and admin_password_encrypted_value to an empty string so a new password may be generated.
    """


@dataclass
class _SetServerResponse:
    server: Optional[Server]


@dataclass
class _SetSnapshotRequest:
    id: str
    name: str
    zone: Optional[ScwZone]
    """
    Zone to target. If none is passed will use default zone from the config.
    """
    organization: Optional[str]
    volume_type: Optional[VolumeVolumeType]
    size: int
    state: Optional[SnapshotState]
    base_volume: Optional[SnapshotBaseVolume]
    creation_date: Optional[datetime]
    modification_date: Optional[datetime]
    project: Optional[str]
    snapshot_id: str
    tags: Optional[List[str]]


@dataclass
class _SetSnapshotResponse:
    snapshot: Optional[Snapshot]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import FlexibleIPStatus
from .content import FLEXIBLE_IP_TRANSIENT_STATUSES
from .types import ListFlexibleIPsRequestOrderBy
from .types import MACAddressStatus
from .content import MAC_ADDRESS_TRANSIENT_STATUSES
from .types import MACAddressType
from .types import MACAddress
from .types import FlexibleIP
from .types import AttachFlexibleIPRequest
from .types import AttachFlexibleIPsResponse
from .types import CreateFlexibleIPRequest
from .types import DeleteFlexibleIPRequest
from .types import DeleteMACAddrRequest
from .types import DetachFlexibleIPRequest
from .types import DetachFlexibleIPsResponse
from .types import DuplicateMACAddrRequest
from .types import GenerateMACAddrRequest
from .types import GetFlexibleIPRequest
from .types import ListFlexibleIPsRequest
from .types import ListFlexibleIPsResponse
from .types import MoveMACAddrRequest
from .types import UpdateFlexibleIPRequest
from .api import FlexibleipV1Alpha1API

__all__ = [
    "FlexibleIPStatus",
    "FLEXIBLE_IP_TRANSIENT_STATUSES",
    "ListFlexibleIPsRequestOrderBy",
    "MACAddressStatus",
    "MAC_ADDRESS_TRANSIENT_STATUSES",
    "MACAddressType",
    "MACAddress",
    "FlexibleIP",
    "AttachFlexibleIPRequest",
    "AttachFlexibleIPsResponse",
    "CreateFlexibleIPRequest",
    "DeleteFlexibleIPRequest",
    "DeleteMACAddrRequest",
    "DetachFlexibleIPRequest",
    "DetachFlexibleIPsResponse",
    "DuplicateMACAddrRequest",
    "GenerateMACAddrRequest",
    "GetFlexibleIPRequest",
    "ListFlexibleIPsRequest",
    "ListFlexibleIPsResponse",
    "MoveMACAddrRequest",
    "UpdateFlexibleIPRequest",
    "FlexibleipV1Alpha1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import AclActionRedirectRedirectType
from .types import AclActionType
from .types import AclHttpFilter
from .types import BackendServerStatsHealthCheckStatus
from .types import BackendServerStatsServerState
from .types import CertificateStatus
from .content import CERTIFICATE_TRANSIENT_STATUSES
from .types import CertificateType
from .types import ForwardPortAlgorithm
from .types import InstanceStatus
from .content import INSTANCE_TRANSIENT_STATUSES
from .types import LbStatus
from .content import LB_TRANSIENT_STATUSES
from .types import LbTypeStock
from .types import ListAclRequestOrderBy
from .types import ListBackendsRequestOrderBy
from .types import ListCertificatesRequestOrderBy
from .types import ListFrontendsRequestOrderBy
from .types import ListIpsRequestIpType
from .types import ListLbsRequestOrderBy
from .types import ListPrivateNetworksRequestOrderBy
from .types import ListRoutesRequestOrderBy
from .types import ListSubscriberRequestOrderBy
from .types import OnMarkedDownAction
from .types import PrivateNetworkStatus
from .content import PRIVATE_NETWORK_TRANSIENT_STATUSES
from .types import Protocol
from .types import ProxyProtocol
from .types import SSLCompatibilityLevel
from .types import StickySessionsType
from .types import SubscriberEmailConfig
from .types import SubscriberWebhookConfig
from .types import HealthCheckHttpConfig
from .types import HealthCheckHttpsConfig
from .types import HealthCheckLdapConfig
from .types import HealthCheckMysqlConfig
from .types import HealthCheckPgsqlConfig
from .types import HealthCheckRedisConfig
from .types import HealthCheckTcpConfig
from .types import Instance
from .types import Ip
from .types import Subscriber
from .types import HealthCheck
from .types import Lb
from .types import AclActionRedirect
from .types import Backend
from .types import Certificate
from .types import AclAction
from .types import AclMatch
from .types import Frontend
from .types import PrivateNetworkDHCPConfig
from .types import PrivateNetworkIpamConfig
from .types import PrivateNetworkStaticConfig
from .types import RouteMatch
from .types import CreateCertificateRequestCustomCertificate
from .types import CreateCertificateRequestLetsencryptConfig
from .types import BackendServerStats
from .types import Acl
from .types import PrivateNetwork
from .types import LbType
from .types import Route
from .types import AclSpec
from .types import AddBackendServersRequest
from .types import AttachPrivateNetworkRequest
from .types import CreateAclRequest
from .types import CreateBackendRequest
from .types import CreateCertificateRequest
from .types import CreateFrontendRequest
from .types import CreateIpRequest
from .types import CreateLbRequest
from .types import CreateRouteRequest
from .types import CreateSubscriberRequest
from .types import DeleteAclRequest
from .types import DeleteBackendRequest
from .types import DeleteCertificateRequest
from .types import DeleteFrontendRequest
from .types import DeleteLbRequest
from .types import DeleteRouteRequest
from .types import DeleteSubscriberRequest
from .types import DetachPrivateNetworkRequest
from .types import GetAclRequest
from .types import GetBackendRequest
from .types import GetCertificateRequest
from .types import GetFrontendRequest
from .types import GetIpRequest
from .types import GetLbRequest
from .types import GetLbStatsRequest
from .types import GetRouteRequest
from .types import GetSubscriberRequest
from .types import LbStats
from .types import ListAclResponse
from .types import ListAclsRequest
from .types import ListBackendStatsRequest
from .types import ListBackendStatsResponse
from .types import ListBackendsRequest
from .types import ListBackendsResponse
from .types import ListCertificatesRequest
from .types import ListCertificatesResponse
from .types import ListFrontendsRequest
from .types import ListFrontendsResponse
from .types import ListIPsRequest
from .types import ListIpsResponse
from .types import ListLbPrivateNetworksRequest
from .types import ListLbPrivateNetworksResponse
from .types import ListLbTypesRequest
from .types import ListLbTypesResponse
from .types import ListLbsRequest
from .types import ListLbsResponse
from .types import ListRoutesRequest
from .types import ListRoutesResponse
from .types import ListSubscriberRequest
from .types import ListSubscriberResponse
from .types import MigrateLbRequest
from .types import ReleaseIpRequest
from .types import RemoveBackendServersRequest
from .types import SetAclsResponse
from .types import SetBackendServersRequest
from .types import SubscribeToLbRequest
from .types import UnsubscribeFromLbRequest
from .types import UpdateAclRequest
from .types import UpdateBackendRequest
from .types import UpdateCertificateRequest
from .types import UpdateFrontendRequest
from .types import UpdateHealthCheckRequest
from .types import UpdateIpRequest
from .types import UpdateLbRequest
from .types import UpdateRouteRequest
from .types import UpdateSubscriberRequest
from .types import ZonedApiAddBackendServersRequest
from .types import ZonedApiAttachPrivateNetworkRequest
from .types import ZonedApiCreateAclRequest
from .types import ZonedApiCreateBackendRequest
from .types import ZonedApiCreateCertificateRequest
from .types import ZonedApiCreateFrontendRequest
from .types import ZonedApiCreateIpRequest
from .types import ZonedApiCreateLbRequest
from .types import ZonedApiCreateRouteRequest
from .types import ZonedApiCreateSubscriberRequest
from .types import ZonedApiDeleteAclRequest
from .types import ZonedApiDeleteBackendRequest
from .types import ZonedApiDeleteCertificateRequest
from .types import ZonedApiDeleteFrontendRequest
from .types import ZonedApiDeleteLbRequest
from .types import ZonedApiDeleteRouteRequest
from .types import ZonedApiDeleteSubscriberRequest
from .types import ZonedApiDetachPrivateNetworkRequest
from .types import ZonedApiGetAclRequest
from .types import ZonedApiGetBackendRequest
from .types import ZonedApiGetCertificateRequest
from .types import ZonedApiGetFrontendRequest
from .types import ZonedApiGetIpRequest
from .types import ZonedApiGetLbRequest
from .types import ZonedApiGetLbStatsRequest
from .types import ZonedApiGetRouteRequest
from .types import ZonedApiGetSubscriberRequest
from .types import ZonedApiListAclsRequest
from .types import ZonedApiListBackendStatsRequest
from .types import ZonedApiListBackendsRequest
from .types import ZonedApiListCertificatesRequest
from .types import ZonedApiListFrontendsRequest
from .types import ZonedApiListIPsRequest
from .types import ZonedApiListLbPrivateNetworksRequest
from .types import ZonedApiListLbTypesRequest
from .types import ZonedApiListLbsRequest
from .types import ZonedApiListRoutesRequest
from .types import ZonedApiListSubscriberRequest
from .types import ZonedApiMigrateLbRequest
from .types import ZonedApiReleaseIpRequest
from .types import ZonedApiRemoveBackendServersRequest
from .types import ZonedApiSetAclsRequest
from .types import ZonedApiSetBackendServersRequest
from .types import ZonedApiSubscribeToLbRequest
from .types import ZonedApiUnsubscribeFromLbRequest
from .types import ZonedApiUpdateAclRequest
from .types import ZonedApiUpdateBackendRequest
from .types import ZonedApiUpdateCertificateRequest
from .types import ZonedApiUpdateFrontendRequest
from .types import ZonedApiUpdateHealthCheckRequest
from .types import ZonedApiUpdateIpRequest
from .types import ZonedApiUpdateLbRequest
from .types import ZonedApiUpdateRouteRequest
from .types import ZonedApiUpdateSubscriberRequest
from .api import LbV1ZonedAPI
from .api import LbV1API

__all__ = [
    "AclActionRedirectRedirectType",
    "AclActionType",
    "AclHttpFilter",
    "BackendServerStatsHealthCheckStatus",
    "BackendServerStatsServerState",
    "CertificateStatus",
    "CERTIFICATE_TRANSIENT_STATUSES",
    "CertificateType",
    "ForwardPortAlgorithm",
    "InstanceStatus",
    "INSTANCE_TRANSIENT_STATUSES",
    "LbStatus",
    "LB_TRANSIENT_STATUSES",
    "LbTypeStock",
    "ListAclRequestOrderBy",
    "ListBackendsRequestOrderBy",
    "ListCertificatesRequestOrderBy",
    "ListFrontendsRequestOrderBy",
    "ListIpsRequestIpType",
    "ListLbsRequestOrderBy",
    "ListPrivateNetworksRequestOrderBy",
    "ListRoutesRequestOrderBy",
    "ListSubscriberRequestOrderBy",
    "OnMarkedDownAction",
    "PrivateNetworkStatus",
    "PRIVATE_NETWORK_TRANSIENT_STATUSES",
    "Protocol",
    "ProxyProtocol",
    "SSLCompatibilityLevel",
    "StickySessionsType",
    "SubscriberEmailConfig",
    "SubscriberWebhookConfig",
    "HealthCheckHttpConfig",
    "HealthCheckHttpsConfig",
    "HealthCheckLdapConfig",
    "HealthCheckMysqlConfig",
    "HealthCheckPgsqlConfig",
    "HealthCheckRedisConfig",
    "HealthCheckTcpConfig",
    "Instance",
    "Ip",
    "Subscriber",
    "HealthCheck",
    "Lb",
    "AclActionRedirect",
    "Backend",
    "Certificate",
    "AclAction",
    "AclMatch",
    "Frontend",
    "PrivateNetworkDHCPConfig",
    "PrivateNetworkIpamConfig",
    "PrivateNetworkStaticConfig",
    "RouteMatch",
    "CreateCertificateRequestCustomCertificate",
    "CreateCertificateRequestLetsencryptConfig",
    "BackendServerStats",
    "Acl",
    "PrivateNetwork",
    "LbType",
    "Route",
    "AclSpec",
    "AddBackendServersRequest",
    "AttachPrivateNetworkRequest",
    "CreateAclRequest",
    "CreateBackendRequest",
    "CreateCertificateRequest",
    "CreateFrontendRequest",
    "CreateIpRequest",
    "CreateLbRequest",
    "CreateRouteRequest",
    "CreateSubscriberRequest",
    "DeleteAclRequest",
    "DeleteBackendRequest",
    "DeleteCertificateRequest",
    "DeleteFrontendRequest",
    "DeleteLbRequest",
    "DeleteRouteRequest",
    "DeleteSubscriberRequest",
    "DetachPrivateNetworkRequest",
    "GetAclRequest",
    "GetBackendRequest",
    "GetCertificateRequest",
    "GetFrontendRequest",
    "GetIpRequest",
    "GetLbRequest",
    "GetLbStatsRequest",
    "GetRouteRequest",
    "GetSubscriberRequest",
    "LbStats",
    "ListAclResponse",
    "ListAclsRequest",
    "ListBackendStatsRequest",
    "ListBackendStatsResponse",
    "ListBackendsRequest",
    "ListBackendsResponse",
    "ListCertificatesRequest",
    "ListCertificatesResponse",
    "ListFrontendsRequest",
    "ListFrontendsResponse",
    "ListIPsRequest",
    "ListIpsResponse",
    "ListLbPrivateNetworksRequest",
    "ListLbPrivateNetworksResponse",
    "ListLbTypesRequest",
    "ListLbTypesResponse",
    "ListLbsRequest",
    "ListLbsResponse",
    "ListRoutesRequest",
    "ListRoutesResponse",
    "ListSubscriberRequest",
    "ListSubscriberResponse",
    "MigrateLbRequest",
    "ReleaseIpRequest",
    "RemoveBackendServersRequest",
    "SetAclsResponse",
    "SetBackendServersRequest",
    "SubscribeToLbRequest",
    "UnsubscribeFromLbRequest",
    "UpdateAclRequest",
    "UpdateBackendRequest",
    "UpdateCertificateRequest",
    "UpdateFrontendRequest",
    "UpdateHealthCheckRequest",
    "UpdateIpRequest",
    "UpdateLbRequest",
    "UpdateRouteRequest",
    "UpdateSubscriberRequest",
    "ZonedApiAddBackendServersRequest",
    "ZonedApiAttachPrivateNetworkRequest",
    "ZonedApiCreateAclRequest",
    "ZonedApiCreateBackendRequest",
    "ZonedApiCreateCertificateRequest",
    "ZonedApiCreateFrontendRequest",
    "ZonedApiCreateIpRequest",
    "ZonedApiCreateLbRequest",
    "ZonedApiCreateRouteRequest",
    "ZonedApiCreateSubscriberRequest",
    "ZonedApiDeleteAclRequest",
    "ZonedApiDeleteBackendRequest",
    "ZonedApiDeleteCertificateRequest",
    "ZonedApiDeleteFrontendRequest",
    "ZonedApiDeleteLbRequest",
    "ZonedApiDeleteRouteRequest",
    "ZonedApiDeleteSubscriberRequest",
    "ZonedApiDetachPrivateNetworkRequest",
    "ZonedApiGetAclRequest",
    "ZonedApiGetBackendRequest",
    "ZonedApiGetCertificateRequest",
    "ZonedApiGetFrontendRequest",
    "ZonedApiGetIpRequest",
    "ZonedApiGetLbRequest",
    "ZonedApiGetLbStatsRequest",
    "ZonedApiGetRouteRequest",
    "ZonedApiGetSubscriberRequest",
    "ZonedApiListAclsRequest",
    "ZonedApiListBackendStatsRequest",
    "ZonedApiListBackendsRequest",
    "ZonedApiListCertificatesRequest",
    "ZonedApiListFrontendsRequest",
    "ZonedApiListIPsRequest",
    "ZonedApiListLbPrivateNetworksRequest",
    "ZonedApiListLbTypesRequest",
    "ZonedApiListLbsRequest",
    "ZonedApiListRoutesRequest",
    "ZonedApiListSubscriberRequest",
    "ZonedApiMigrateLbRequest",
    "ZonedApiReleaseIpRequest",
    "ZonedApiRemoveBackendServersRequest",
    "ZonedApiSetAclsRequest",
    "ZonedApiSetBackendServersRequest",
    "ZonedApiSubscribeToLbRequest",
    "ZonedApiUnsubscribeFromLbRequest",
    "ZonedApiUpdateAclRequest",
    "ZonedApiUpdateBackendRequest",
    "ZonedApiUpdateCertificateRequest",
    "ZonedApiUpdateFrontendRequest",
    "ZonedApiUpdateHealthCheckRequest",
    "ZonedApiUpdateIpRequest",
    "ZonedApiUpdateLbRequest",
    "ZonedApiUpdateRouteRequest",
    "ZonedApiUpdateSubscriberRequest",
    "LbV1ZonedAPI",
    "LbV1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import Dict, List, Optional

from scaleway_core.bridge import (
    Region as ScwRegion,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class JobRunState(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATE = "unknown_state"
    QUEUED = "queued"
    SCHEDULED = "scheduled"
    RUNNING = "running"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"
    INTERNAL_ERROR = "internal_error"

    def __str__(self) -> str:
        return str(self.value)


class ListJobDefinitionsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListJobRunsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class SecretEnvVar:
    name: str


@dataclass
class SecretFile:
    path: str


@dataclass
class CronSchedule:
    schedule: str
    """
    UNIX cron schedule to run job (e.g., '* * * * *').
    """

    timezone: str
    """
    Timezone for the cron schedule, in tz database format (e.g., 'Europe/Paris').
    """


@dataclass
class CreateJobDefinitionRequestCronScheduleConfig:
    schedule: str

    timezone: str


@dataclass
class CreateJobDefinitionSecretsRequestSecretConfig:
    secret_manager_id: str

    secret_manager_version: str

    path: Optional[str]

    env_var_name: Optional[str]


@dataclass
class Secret:
    secret_id: str
    """
    UUID of the secret reference within the job.
    """

    secret_manager_id: str
    """
    UUID of the secret in Secret Manager.
    """

    secret_manager_version: str
    """
    Version of the secret in Secret Manager.
    """

    file: Optional[SecretFile]

    env_var: Optional[SecretEnvVar]


@dataclass
class JobDefinition:
    id: str

    name: str

    cpu_limit: int

    memory_limit: int

    image_uri: str

    command: str

    project_id: str

    created_at: Optional[datetime]

    updated_at: Optional[datetime]

    environment_variables: Dict[str, str]

    description: str

    local_storage_capacity: int

    region: ScwRegion
    """
    Region to target. If none is passed will use default region from the config.
    """

    job_timeout: Optional[str]

    cron_schedule: Optional[CronSchedule]


@dataclass
class JobRun:
    id: str

    job_definition_id: str

    state: JobRunState

    error_message: str

    cpu_limit: int

    memory_limit: int

    command: str

    created_at: Optional[datetime]

    updated_at: Optional[datetime]

    terminated_at: Optional[datetime]

    exit_code: Optional[int]

    run_duration: Optional[str]

    environment_variables: Dict[str, str]

    local_storage_capacity: int

    region: ScwRegion
    """
    Region to target. If none is passed will use default region from the config.
    """

    started_at: Optional[datetime]


@dataclass
class Resource:
    cpu_limit: int

    memory_limit: int


@dataclass
class UpdateJobDefinitionRequestCronScheduleConfig:
    schedule: Optional[str]

    timezone: Optional[str]


@dataclass
class CreateJobDefinitionRequest:
    cpu_limit: int
    """
    CPU limit of the job.
    """

    memory_limit: int
    """
    Memory limit of the job (in MiB).
    """

    image_uri: str
    """
    Image to use for the job.
    """

    command: str
    """
    Startup command. If empty or not defined, the image's default command is used.
    """

    description: str
    """
    Description of the job.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    name: Optional[str]
    """
    Name of the job definition.
    """

    local_storage_capacity: Optional[int]
    """
    Local storage capacity of the job (in MiB).
    """

    project_id: Optional[str]
    """
    UUID of the Scaleway Project containing the job.
    """

    environment_variables: Optional[Dict[str, str]]
    """
    Environment variables of the job.
    """

    job_timeout: Optional[str]
    """
    Timeout of the job in seconds.
    """

    cron_schedule: Optional[CreateJobDefinitionRequestCronScheduleConfig]
    """
    Configure a cron for the job.
    """


@dataclass
class CreateJobDefinitionSecretsRequest:
    job_definition_id: str
    """
    UUID of the job definition.
    """

    secrets: List[CreateJobDefinitionSecretsRequestSecretConfig]
    """
    List of secrets to inject into the job.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class CreateJobDefinitionSecretsResponse:
    secrets: List[Secret]
    """
    List of secrets created.
    """


@dataclass
class DeleteJobDefinitionRequest:
    job_definition_id: str
    """
    UUID of the job definition to delete.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class DeleteJobDefinitionSecretRequest:
    job_definition_id: str
    """
    UUID of the job definition.
    """

    secret_id: str
    """
    UUID of the secret reference within the job.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetJobDefinitionRequest:
    job_definition_id: str
    """
    UUID of the job definition to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetJobDefinitionSecretRequest:
    job_definition_id: str
    """
    UUID of the job definition.
    """

    secret_id: str
    """
    UUID of the secret reference within the job.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetJobRunRequest:
    job_run_id: str
    """
    UUID of the job run to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetJobsLimitsRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class JobsLimits:
    secrets_per_job_definition: int


@dataclass
class ListJobDefinitionSecretsRequest:
    job_definition_id: str
    """
    UUID of the job definition.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class ListJobDefinitionSecretsResponse:
    secrets: List[Secret]
    """
    List of secret references within a job definition.
    """

    total_count: int
    """
    Total count of secret references within a job definition.
    """


@dataclass
class ListJobDefinitionsRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]

    page_size: Optional[int]

    order_by: Optional[ListJobDefinitionsRequestOrderBy]

    project_id: Optional[str]

    organization_id: Optional[str]


@dataclass
class ListJobDefinitionsResponse:
    job_definitions: List[JobDefinition]

    total_count: int


@dataclass
class ListJobRunsRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]

    page_size: Optional[int]

    order_by: Optional[ListJobRunsRequestOrderBy]

    job_definition_id: Optional[str]

    project_id: Optional[str]

    organization_id: Optional[str]

    state: Optional[JobRunState]


@dataclass
class ListJobRunsResponse:
    job_runs: List[JobRun]

    total_count: int


@dataclass
class ListJobsResourcesRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class ListJobsResourcesResponse:
    resources: List[Resource]


@dataclass
class StartJobDefinitionRequest:
    job_definition_id: str
    """
    UUID of the job definition to start.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    command: Optional[str]
    """
    Contextual startup command for this specific job run.
    """

    environment_variables: Optional[Dict[str, str]]
    """
    Contextual environment variables for this specific job run.
    """

    replicas: Optional[int]
    """
    Number of jobs to run.
    """


@dataclass
class StartJobDefinitionResponse:
    job_runs: List[JobRun]


@dataclass
class StopJobRunRequest:
    job_run_id: str
    """
    UUID of the job run to stop.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class UpdateJobDefinitionRequest:
    job_definition_id: str
    """
    UUID of the job definition to update.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    name: Optional[str]
    """
    Name of the job definition.
    """

    cpu_limit: Optional[int]
    """
    CPU limit of the job.
    """

    memory_limit: Optional[int]
    """
    Memory limit of the job (in MiB).
    """

    local_storage_capacity: Optional[int]
    """
    Local storage capacity of the job (in MiB).
    """

    image_uri: Optional[str]
    """
    Image to use for the job.
    """

    command: Optional[str]
    """
    Startup command.
    """

    environment_variables: Optional[Dict[str, str]]
    """
    Environment variables of the job.
    """

    description: Optional[str]
    """
    Description of the job.
    """

    job_timeout: Optional[str]
    """
    Timeout of the job in seconds.
    """

    cron_schedule: Optional[UpdateJobDefinitionRequestCronScheduleConfig]


@dataclass
class UpdateJobDefinitionSecretRequest:
    job_definition_id: str
    """
    UUID of the job definition.
    """

    secret_id: str
    """
    UUID of the secret reference within the job.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    secret_manager_version: Optional[str]
    """
    Version of the secret in Secret Manager.
    """

    path: Optional[str]

    env_var_name: Optional[str]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import BlocklistType
from .types import DomainLastStatusAutoconfigStateReason
from .types import DomainLastStatusRecordStatus
from .types import DomainReputationStatus
from .types import DomainStatus
from .content import DOMAIN_TRANSIENT_STATUSES
from .types import EmailFlag
from .types import EmailRcptType
from .types import EmailStatus
from .content import EMAIL_TRANSIENT_STATUSES
from .types import ListBlocklistsRequestOrderBy
from .types import ListEmailsRequestOrderBy
from .types import ListWebhookEventsRequestOrderBy
from .types import ListWebhooksRequestOrderBy
from .types import OfferName
from .types import PoolStatus
from .types import ProjectSettingsPeriodicReportFrequency
from .types import WebhookEventStatus
from .types import WebhookEventType
from .types import DomainRecordsDMARC
from .types import EmailTry
from .types import DomainRecords
from .types import DomainReputation
from .types import DomainStatistics
from .types import Blocklist
from .types import CreateEmailRequestAddress
from .types import CreateEmailRequestAttachment
from .types import CreateEmailRequestHeader
from .types import Email
from .types import DomainLastStatusAutoconfigState
from .types import DomainLastStatusDkimRecord
from .types import DomainLastStatusDmarcRecord
from .types import DomainLastStatusSpfRecord
from .types import Domain
from .types import OfferSubscription
from .types import Offer
from .types import Pool
from .types import WebhookEvent
from .types import Webhook
from .types import ProjectSettingsPeriodicReport
from .types import UpdateProjectSettingsRequestUpdatePeriodicReport
from .types import BulkCreateBlocklistsRequest
from .types import BulkCreateBlocklistsResponse
from .types import CancelEmailRequest
from .types import CheckDomainRequest
from .types import CreateDomainRequest
from .types import CreateEmailRequest
from .types import CreateEmailResponse
from .types import CreateWebhookRequest
from .types import DeleteBlocklistRequest
from .types import DeleteWebhookRequest
from .types import DomainLastStatus
from .types import GetDomainLastStatusRequest
from .types import GetDomainRequest
from .types import GetEmailRequest
from .types import GetProjectConsumptionRequest
from .types import GetProjectSettingsRequest
from .types import GetStatisticsRequest
from .types import GetWebhookRequest
from .types import ListBlocklistsRequest
from .types import ListBlocklistsResponse
from .types import ListDomainsRequest
from .types import ListDomainsResponse
from .types import ListEmailsRequest
from .types import ListEmailsResponse
from .types import ListOfferSubscriptionsRequest
from .types import ListOfferSubscriptionsResponse
from .types import ListOffersRequest
from .types import ListOffersResponse
from .types import ListPoolsRequest
from .types import ListPoolsResponse
from .types import ListWebhookEventsRequest
from .types import ListWebhookEventsResponse
from .types import ListWebhooksRequest
from .types import ListWebhooksResponse
from .types import ProjectConsumption
from .types import ProjectSettings
from .types import RevokeDomainRequest
from .types import Statistics
from .types import UpdateDomainRequest
from .types import UpdateOfferSubscriptionRequest
from .types import UpdateProjectSettingsRequest
from .types import UpdateWebhookRequest
from .api import TemV1Alpha1API

__all__ = [
    "BlocklistType",
    "DomainLastStatusAutoconfigStateReason",
    "DomainLastStatusRecordStatus",
    "DomainReputationStatus",
    "DomainStatus",
    "DOMAIN_TRANSIENT_STATUSES",
    "EmailFlag",
    "EmailRcptType",
    "EmailStatus",
    "EMAIL_TRANSIENT_STATUSES",
    "ListBlocklistsRequestOrderBy",
    "ListEmailsRequestOrderBy",
    "ListWebhookEventsRequestOrderBy",
    "ListWebhooksRequestOrderBy",
    "OfferName",
    "PoolStatus",
    "ProjectSettingsPeriodicReportFrequency",
    "WebhookEventStatus",
    "WebhookEventType",
    "DomainRecordsDMARC",
    "EmailTry",
    "DomainRecords",
    "DomainReputation",
    "DomainStatistics",
    "Blocklist",
    "CreateEmailRequestAddress",
    "CreateEmailRequestAttachment",
    "CreateEmailRequestHeader",
    "Email",
    "DomainLastStatusAutoconfigState",
    "DomainLastStatusDkimRecord",
    "DomainLastStatusDmarcRecord",
    "DomainLastStatusSpfRecord",
    "Domain",
    "OfferSubscription",
    "Offer",
    "Pool",
    "WebhookEvent",
    "Webhook",
    "ProjectSettingsPeriodicReport",
    "UpdateProjectSettingsRequestUpdatePeriodicReport",
    "BulkCreateBlocklistsRequest",
    "BulkCreateBlocklistsResponse",
    "CancelEmailRequest",
    "CheckDomainRequest",
    "CreateDomainRequest",
    "CreateEmailRequest",
    "CreateEmailResponse",
    "CreateWebhookRequest",
    "DeleteBlocklistRequest",
    "DeleteWebhookRequest",
    "DomainLastStatus",
    "GetDomainLastStatusRequest",
    "GetDomainRequest",
    "GetEmailRequest",
    "GetProjectConsumptionRequest",
    "GetProjectSettingsRequest",
    "GetStatisticsRequest",
    "GetWebhookRequest",
    "ListBlocklistsRequest",
    "ListBlocklistsResponse",
    "ListDomainsRequest",
    "ListDomainsResponse",
    "ListEmailsRequest",
    "ListEmailsResponse",
    "ListOfferSubscriptionsRequest",
    "ListOfferSubscriptionsResponse",
    "ListOffersRequest",
    "ListOffersResponse",
    "ListPoolsRequest",
    "ListPoolsResponse",
    "ListWebhookEventsRequest",
    "ListWebhookEventsResponse",
    "ListWebhooksRequest",
    "ListWebhooksResponse",
    "ProjectConsumption",
    "ProjectSettings",
    "RevokeDomainRequest",
    "Statistics",
    "UpdateDomainRequest",
    "UpdateOfferSubscriptionRequest",
    "UpdateProjectSettingsRequest",
    "UpdateWebhookRequest",
    "TemV1Alpha1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from datetime import datetime
from typing import Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Region as ScwRegion,
)
from scaleway_core.utils import (
    validate_path_param,
)
from .types import (
    ListEventsRequestOrderBy,
    ResourceType,
    ListEventsResponse,
    ListProductsResponse,
)
from .marshalling import (
    unmarshal_ListEventsResponse,
    unmarshal_ListProductsResponse,
)


class AuditTrailV1Alpha1API(API):
    """
    This API allows you to ensure accountability and security by recording events and changes performed within your Scaleway Organization.
    """

    def list_events(
        self,
        *,
        region: Optional[ScwRegion] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        resource_type: Optional[ResourceType] = None,
        method_name: Optional[str] = None,
        status: Optional[int] = None,
        recorded_after: Optional[datetime] = None,
        recorded_before: Optional[datetime] = None,
        order_by: Optional[ListEventsRequestOrderBy] = None,
        page_size: Optional[int] = None,
        page_token: Optional[str] = None,
        product_name: Optional[str] = None,
        service_name: Optional[str] = None,
    ) -> ListEventsResponse:
        """
        List events.
        Retrieve the list of Audit Trail events for a Scaleway Organization and/or Project. You must specify the `organization_id` and optionally, the `project_id`.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: (Optional) ID of the Project containing the Audit Trail events.
        :param organization_id: ID of the Organization containing the Audit Trail events.
        :param resource_type: (Optional) Returns a paginated list of Scaleway resources' features.
        :param method_name: (Optional) Name of the method of the API call performed.
        :param status: (Optional) HTTP status code of the request. Returns either `200` if the request was successful or `403` if the permission was denied.
        :param recorded_after: (Optional) The `recorded_after` parameter defines the earliest timestamp from which Audit Trail events are retrieved. Returns `one hour ago` by default.
        :param recorded_before: (Optional) The `recorded_before` parameter defines the latest timestamp up to which Audit Trail events are retrieved. Returns `now` by default.
        :param order_by:
        :param page_size:
        :param page_token:
        :param product_name: (Optional) Name of the Scaleway resource in a hyphenated format.
        :param service_name: (Optional) Name of the service of the API call performed.
        :return: :class:`ListEventsResponse <ListEventsResponse>`

        Usage:
        ::

            result = api.list_events()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/audit-trail/v1alpha1/regions/{param_region}/events",
            params={
                "method_name": method_name,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page_size": page_size or self.client.default_page_size,
                "page_token": page_token,
                "product_name": product_name,
                "project_id": project_id or self.client.default_project_id,
                "recorded_after": recorded_after,
                "recorded_before": recorded_before,
                "resource_type": resource_type,
                "service_name": service_name,
                "status": status,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListEventsResponse(res.json())

    def list_products(
        self,
        *,
        region: Optional[ScwRegion] = None,
        organization_id: Optional[str] = None,
    ) -> ListProductsResponse:
        """
        Retrieve the list of Scaleway resources for which you have Audit Trail events.
        :param region: Region to target. If none is passed will use default region from the config.
        :param organization_id: ID of the Organization containing the Audit Trail events.
        :return: :class:`ListProductsResponse <ListProductsResponse>`

        Usage:
        ::

            result = api.list_products()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/audit-trail/v1alpha1/regions/{param_region}/products",
            params={
                "organization_id": organization_id
                or self.client.default_organization_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListProductsResponse(res.json())
